@@ -32,6 +32,7 @@
 int main(int argc, char *argv[])
 {
     QCoreApplication app(argc, argv);
+    KLocalizedString::setApplicationDomain("kbroadcastnotification");
 
     KAboutData aboutData("kbroadcastnotification", i18n("Broadcast Notifications"),
                          PROJECT_VERSION,
@@ -61,6 +62,7 @@ int main(int argc, char *argv[])
     parser.addPositionalArgument(QStringLiteral("body"), i18n("The actual notification body text"));
 
     parser.process(app);
+    aboutData.processCommandLine(&parser);
 
     QVariantMap properties;
     if (parser.isSet(applicationNameOption)) {
