@@ -31,7 +31,7 @@ int main( int argc, char **argv )
 {
     QCoreApplication app(argc, argv);
 
-    KLocalizedString::setApplicationDomain("ktraderclient");
+    KLocalizedString::setApplicationDomain("ktraderclient5");
     KAboutData aboutData(QLatin1String("ktraderclient"), i18n("KTraderClient"), QLatin1String(PROJECT_VERSION));
     aboutData.addAuthor(i18n("David Faure"), QString(), "faure@kde.org");
 
@@ -42,11 +42,11 @@ int main( int argc, char **argv )
     parser.addHelpOption();
     aboutData.setupCommandLine(&parser);
 
-    parser.addOption(QCommandLineOption(QStringList() << QLatin1String("mimetype"), i18n("A mimetype"), QLatin1String("mimetype")));
+    parser.addOption(QCommandLineOption(QStringList() << QLatin1String("mimetype"), i18n("A MIME type"), QLatin1String("mimetype")));
     parser.addOption(QCommandLineOption(QStringList() << QLatin1String("servicetype"), i18n("A servicetype, like KParts/ReadOnlyPart or KMyApp/Plugin"), QLatin1String("servicetype")));
     parser.addOption(QCommandLineOption(QStringList() << QLatin1String("constraint"), i18n("A constraint expressed in the trader query language"), QLatin1String("constraint")));
 
-    parser.addOption(QCommandLineOption(QStringList() << QLatin1String("properties"), i18n("Output all properties")));
+    parser.addOption(QCommandLineOption(QStringList() << QLatin1String("short"), i18n("Output only paths to desktop files")));
 
     parser.process(app);
     aboutData.processCommandLine(&parser);
@@ -54,7 +54,7 @@ int main( int argc, char **argv )
     const QString mimetype = parser.value("mimetype");
     QString servicetype = parser.value("servicetype");
     const QString constraint = parser.value("constraint");
-    const bool outputProperties = parser.isSet("properties");
+    const bool outputProperties = !parser.isSet("short");
 
     if ( mimetype.isEmpty() && servicetype.isEmpty() )
         parser.showHelp();
